@@ -18,7 +18,7 @@ our @EXPORT_OK = (@EXPORT, map {@$_} values %EXPORT_TAGS);
 sub myMakeHelper {
     my %ret = ();
 
-    warn __PACKAGE__, "\tAUTOMATED_TESTING = ", $ENV{AUTOMATED_TESTING}//'<undef>', "\n";
+    warn __PACKAGE__, "\tAUTOMATED_CI_TESTING = ", $ENV{AUTOMATED_CI_TESTING}//'<undef>', "\n";
     warn __PACKAGE__, "\tTEMP = ", $ENV{TEMP}//'<undef>', "\n";
     warn __PACKAGE__, "\tTMP = ", $ENV{TMP}//'<undef>', "\n";
 
@@ -28,7 +28,7 @@ sub myMakeHelper {
         # need to know bitness _before_ checking for NPP existing
         $ret{bits} = determine_bitness() or last;                               # if your Perl isn't 32-bit or 64-bit, cannot determine the necessary Notepad++ to download
 
-        unless($ENV{AUTOMATED_TESTING}) {                                       # if not automated, then don't need to
+        unless($ENV{AUTOMATED_CI_TESTING}) {                                       # if not automated, then don't need to
             if( my $nppexe = npp_already_exists($ret{bits}) ) {                 # if notepad++ already found, don't need to download it; make sure I set the variables
                 my ($vol, $dir, $fil) = File::Spec->splitpath($nppexe);
                 $ret{npp_folder} = File::Spec->catpath($vol, $dir, '');
