@@ -1,18 +1,29 @@
 // This file is part of Notepad++ project
-// Copyright (C)2021 Don HO <don.h@free.fr>
-
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// at your option any later version.
+// Copyright (C)2020 Don HO <don.h@free.fr>
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+//
+// Note that the GPL places important restrictions on "derived works", yet
+// it does not provide a detailed definition of that term.  To avoid      
+// misunderstandings, we consider an application to constitute a          
+// "derivative work" for the purpose of this license if it does any of the
+// following:                                                             
+// 1. Integrates source code from Notepad++.
+// 2. Integrates/includes/aggregates Notepad++ into a proprietary executable
+//    installer, such as those produced by InstallShield.
+// 3. Links to a library or executes a program that does any of the above.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <https://www.gnu.org/licenses/>.
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 
 #pragma once
@@ -68,7 +79,7 @@
 //10  Rename...
 //11  Close
 //12  Close All
-//13  Close Multiple Documents
+//13  Close More
 //14  Move to Recycle Bin
 //15  --------
 //16  Load Session...
@@ -164,20 +175,11 @@
     #define    IDM_EDIT_SORTLINES_LEXICO_CASE_INSENS_ASCENDING  (IDM_EDIT + 80)
     #define    IDM_EDIT_SORTLINES_LEXICO_CASE_INSENS_DESCENDING (IDM_EDIT + 81)
     #define    IDM_EDIT_COPY_LINK                               (IDM_EDIT + 82)
-    #define    IDM_EDIT_SORTLINES_REVERSE_ORDER                 (IDM_EDIT + 83)
-    #define    IDM_EDIT_INSERT_DATETIME_SHORT                   (IDM_EDIT + 84)
-    #define    IDM_EDIT_INSERT_DATETIME_LONG                    (IDM_EDIT + 85)
-    #define    IDM_EDIT_INSERT_DATETIME_CUSTOMIZED              (IDM_EDIT + 86)
-    #define    IDM_EDIT_COPY_ALL_NAMES                          (IDM_EDIT + 87)
-    #define    IDM_EDIT_COPY_ALL_PATHS                          (IDM_EDIT + 88)
-    #define    IDM_EDIT_BEGINENDSELECT_COLUMNMODE               (IDM_EDIT + 89)
 
     #define    IDM_EDIT_AUTOCOMPLETE                            (50000 + 0)
     #define    IDM_EDIT_AUTOCOMPLETE_CURRENTFILE                (50000 + 1)
     #define    IDM_EDIT_FUNCCALLTIP                             (50000 + 2)
     #define    IDM_EDIT_AUTOCOMPLETE_PATH                       (50000 + 6)
-    #define    IDM_EDIT_FUNCCALLTIP_PREVIOUS                    (50000 + 10)
-    #define    IDM_EDIT_FUNCCALLTIP_NEXT                        (50000 + 11)
 
     
 #define    IDM_SEARCH    (IDM + 3000)
@@ -245,17 +247,9 @@
     #define    IDM_SEARCH_ALLSTYLESTOCLIP      (IDM_SEARCH + 60)
     #define    IDM_SEARCH_MARKEDTOCLIP         (IDM_SEARCH + 61)
 
-    #define    IDM_SEARCH_MARKONEEXT1          (IDM_SEARCH + 62)
-    #define    IDM_SEARCH_MARKONEEXT2          (IDM_SEARCH + 63)
-    #define    IDM_SEARCH_MARKONEEXT3          (IDM_SEARCH + 64)
-    #define    IDM_SEARCH_MARKONEEXT4          (IDM_SEARCH + 65)
-    #define    IDM_SEARCH_MARKONEEXT5          (IDM_SEARCH + 66)
-
 #define    IDM_MISC    (IDM + 3500)
-    #define    IDM_DOCLIST_FILESCLOSE             (IDM_MISC + 1)
-    #define    IDM_DOCLIST_FILESCLOSEOTHERS       (IDM_MISC + 2)
-    #define    IDM_DOCLIST_COPYNAMES              (IDM_MISC + 3)
-    #define    IDM_DOCLIST_COPYPATHS              (IDM_MISC + 4)
+    #define    IDM_FILESWITCHER_FILESCLOSE            (IDM_MISC + 1)
+    #define    IDM_FILESWITCHER_FILESCLOSEOTHERS      (IDM_MISC + 2)
 
 
 #define IDM_VIEW    (IDM + 4000)                
@@ -268,8 +262,8 @@
     #define    IDM_VIEW_DRAWTABBAR_TOPBAR         (IDM_VIEW + 7)
     #define    IDM_VIEW_DRAWTABBAR_INACIVETAB     (IDM_VIEW + 8) 
     #define    IDM_VIEW_POSTIT                    (IDM_VIEW + 9)
-    #define    IDM_VIEW_FOLDALL                   (IDM_VIEW + 10)
-    #define    IDM_VIEW_DISTRACTIONFREE           (IDM_VIEW + 11)
+    #define    IDM_VIEW_TOGGLE_FOLDALL            (IDM_VIEW + 10)
+    //#define    IDM_VIEW_USER_DLG                  (IDM_VIEW + 11)
     #define    IDM_VIEW_LINENUMBER                (IDM_VIEW + 12)
     #define    IDM_VIEW_SYMBOLMARGIN              (IDM_VIEW + 13)
     #define    IDM_VIEW_FOLDERMAGIN               (IDM_VIEW + 14)
@@ -285,9 +279,9 @@
     #define    IDM_VIEW_ZOOMOUT                   (IDM_VIEW + 24)
     #define    IDM_VIEW_TAB_SPACE                 (IDM_VIEW + 25)
     #define    IDM_VIEW_EOL                       (IDM_VIEW + 26)
-    #define    IDM_VIEW_TOOLBAR_REDUCE_SET2       (IDM_VIEW + 27)
-    #define    IDM_VIEW_TOOLBAR_ENLARGE_SET2      (IDM_VIEW + 28)
-    #define    IDM_VIEW_UNFOLDALL                 (IDM_VIEW + 29)
+    //#define    IDM_VIEW_EDGELINE                  (IDM_VIEW + 27)
+    //#define    IDM_VIEW_EDGEBACKGROUND            (IDM_VIEW + 28)
+    #define    IDM_VIEW_TOGGLE_UNFOLDALL          (IDM_VIEW + 29)
     #define    IDM_VIEW_FOLD_CURRENT              (IDM_VIEW + 30)
     #define    IDM_VIEW_UNFOLD_CURRENT            (IDM_VIEW + 31)
     #define    IDM_VIEW_FULLSCREENTOGGLE          (IDM_VIEW + 32)
@@ -303,7 +297,7 @@
     #define    IDM_VIEW_HIDELINES                 (IDM_VIEW + 42)
     #define    IDM_VIEW_DRAWTABBAR_VERTICAL       (IDM_VIEW + 43)
     #define    IDM_VIEW_DRAWTABBAR_MULTILINE      (IDM_VIEW + 44)
-    //#define    IDM_VIEW_DOCCHANGEMARGIN           (IDM_VIEW + 45)
+    #define    IDM_VIEW_DOCCHANGEMARGIN           (IDM_VIEW + 45)
     #define    IDM_VIEW_LWDEF                     (IDM_VIEW + 46)
     #define    IDM_VIEW_LWALIGN                   (IDM_VIEW + 47)
     #define    IDM_VIEW_LWINDENT                  (IDM_VIEW + 48)
@@ -329,7 +323,7 @@
         #define    IDM_VIEW_UNFOLD_7    (IDM_VIEW_UNFOLD + 7)
         #define    IDM_VIEW_UNFOLD_8    (IDM_VIEW_UNFOLD + 8)
     
-    #define    IDM_VIEW_DOCLIST                   (IDM_VIEW + 70)
+    #define    IDM_VIEW_FILESWITCHER_PANEL        (IDM_VIEW + 70)
     #define    IDM_VIEW_SWITCHTO_OTHER_VIEW       (IDM_VIEW + 72)
     #define    IDM_EXPORT_FUNC_LIST_AND_QUIT      (IDM_VIEW + 73)
 
@@ -366,17 +360,6 @@
     #define    IDM_VIEW_SWITCHTO_PROJECT_PANEL_3  (IDM_VIEW + 106)
     #define    IDM_VIEW_SWITCHTO_FILEBROWSER      (IDM_VIEW + 107)
     #define    IDM_VIEW_SWITCHTO_FUNC_LIST        (IDM_VIEW + 108)
-    #define    IDM_VIEW_SWITCHTO_DOCLIST          (IDM_VIEW + 109)
-
-    #define    IDM_VIEW_TAB_COLOUR_NONE           (IDM_VIEW + 110)
-    #define    IDM_VIEW_TAB_COLOUR_1              (IDM_VIEW + 111)
-    #define    IDM_VIEW_TAB_COLOUR_2              (IDM_VIEW + 112)
-    #define    IDM_VIEW_TAB_COLOUR_3              (IDM_VIEW + 113)
-    #define    IDM_VIEW_TAB_COLOUR_4              (IDM_VIEW + 114)
-    #define    IDM_VIEW_TAB_COLOUR_5              (IDM_VIEW + 115)
-
-    #define    IDM_VIEW_NPC                       (IDM_VIEW + 130)
-    #define    IDM_VIEW_NPC_CCUNIEOL              (IDM_VIEW + 131)
 
     #define    IDM_VIEW_GOTO_ANOTHER_VIEW        10001
     #define    IDM_VIEW_CLONE_TO_ANOTHER_VIEW    10002
@@ -390,14 +373,14 @@
     #define    IDM_FORMAT_TOMAC             (IDM_FORMAT + 3)
     #define    IDM_FORMAT_ANSI              (IDM_FORMAT + 4)
     #define    IDM_FORMAT_UTF_8             (IDM_FORMAT + 5)
-    #define    IDM_FORMAT_UTF_16BE          (IDM_FORMAT + 6)
-    #define    IDM_FORMAT_UTF_16LE          (IDM_FORMAT + 7)
+    #define    IDM_FORMAT_UCS_2BE           (IDM_FORMAT + 6)
+    #define    IDM_FORMAT_UCS_2LE           (IDM_FORMAT + 7)
     #define    IDM_FORMAT_AS_UTF_8          (IDM_FORMAT + 8)
     #define    IDM_FORMAT_CONV2_ANSI        (IDM_FORMAT + 9)
     #define    IDM_FORMAT_CONV2_AS_UTF_8    (IDM_FORMAT + 10)
     #define    IDM_FORMAT_CONV2_UTF_8       (IDM_FORMAT + 11)
-    #define    IDM_FORMAT_CONV2_UTF_16BE    (IDM_FORMAT + 12)
-    #define    IDM_FORMAT_CONV2_UTF_16LE    (IDM_FORMAT + 13)
+    #define    IDM_FORMAT_CONV2_UCS_2BE     (IDM_FORMAT + 12)
+    #define    IDM_FORMAT_CONV2_UCS_2LE     (IDM_FORMAT + 13)
 
     #define    IDM_FORMAT_ENCODE            (IDM_FORMAT + 20)
     #define    IDM_FORMAT_WIN_1250          (IDM_FORMAT_ENCODE + 0)
@@ -528,7 +511,7 @@
     #define    IDM_LANG_FORTH              (IDM_LANG + 72)
     #define    IDM_LANG_LATEX              (IDM_LANG + 73)
     #define    IDM_LANG_MMIXAL             (IDM_LANG + 74)
-    #define    IDM_LANG_NIM                (IDM_LANG + 75)
+    #define    IDM_LANG_NIMROD             (IDM_LANG + 75)
     #define    IDM_LANG_NNCRONTAB          (IDM_LANG + 76)
     #define    IDM_LANG_OSCRIPT            (IDM_LANG + 77)
     #define    IDM_LANG_REBOL              (IDM_LANG + 78)
@@ -537,12 +520,7 @@
     #define    IDM_LANG_SPICE              (IDM_LANG + 81)
     #define    IDM_LANG_TXT2TAGS           (IDM_LANG + 82)
     #define    IDM_LANG_VISUALPROLOG       (IDM_LANG + 83)
-    #define    IDM_LANG_TYPESCRIPT         (IDM_LANG + 84)
-    #define    IDM_LANG_JSON5              (IDM_LANG + 85)
-    #define    IDM_LANG_MSSQL              (IDM_LANG + 86)
-    #define    IDM_LANG_GDSCRIPT           (IDM_LANG + 87)
-    #define    IDM_LANG_HOLLYWOOD          (IDM_LANG + 88)
-    
+
     #define    IDM_LANG_EXTERNAL           (IDM_LANG + 165)
     #define    IDM_LANG_EXTERNAL_LIMIT     (IDM_LANG + 179)
 
@@ -550,7 +528,6 @@
     #define    IDM_LANG_USER_LIMIT         (IDM_LANG + 210)     //46210: Ajust with IDM_LANG_USER
     #define    IDM_LANG_USER_DLG           (IDM_LANG + 250)     //46250: Used for translation
     #define    IDM_LANG_OPENUDLDIR         (IDM_LANG + 300)
-    #define    IDM_LANG_UDLCOLLECTION_PROJECT_SITE   (IDM_LANG + 301)
 
 
 
@@ -565,7 +542,7 @@
     //#define    IDM_HELP             (IDM_ABOUT  + 8)
     #define    IDM_CONFUPDATERPROXY (IDM_ABOUT  + 9)
     #define    IDM_CMDLINEARGUMENTS (IDM_ABOUT  + 10)
-    //#define    IDM_ONLINESUPPORT    (IDM_ABOUT  + 11)
+    #define    IDM_ONLINESUPPORT    (IDM_ABOUT  + 11)
     #define    IDM_DEBUGINFO        (IDM_ABOUT  + 12)
 
 
@@ -602,22 +579,3 @@
     #define IDM_SYSTRAYPOPUP_NEW_AND_PASTE    (IDM_SYSTRAYPOPUP + 3)
     #define IDM_SYSTRAYPOPUP_OPENFILE         (IDM_SYSTRAYPOPUP + 4)
     #define IDM_SYSTRAYPOPUP_CLOSE            (IDM_SYSTRAYPOPUP + 5)
-
-#define IDR_WINDOWS_MENU 11000
-    #define  IDM_WINDOW_WINDOWS   	(IDR_WINDOWS_MENU + 1)
-    #define  IDM_WINDOW_SORT_FN_ASC	(IDR_WINDOWS_MENU + 2)
-    #define  IDM_WINDOW_SORT_FN_DSC	(IDR_WINDOWS_MENU + 3)
-    #define  IDM_WINDOW_SORT_FP_ASC	(IDR_WINDOWS_MENU + 4)
-    #define  IDM_WINDOW_SORT_FP_DSC	(IDR_WINDOWS_MENU + 5)
-    #define  IDM_WINDOW_SORT_FT_ASC	(IDR_WINDOWS_MENU + 6)
-    #define  IDM_WINDOW_SORT_FT_DSC	(IDR_WINDOWS_MENU + 7)
-    #define  IDM_WINDOW_SORT_FS_ASC	(IDR_WINDOWS_MENU + 8)
-    #define  IDM_WINDOW_SORT_FS_DSC	(IDR_WINDOWS_MENU + 9)
-    #define  IDM_WINDOW_MRU_FIRST 	(IDR_WINDOWS_MENU + 20)
-    #define  IDM_WINDOW_MRU_LIMIT 	(IDR_WINDOWS_MENU + 59)
-    #define  IDM_WINDOW_COPY_NAME 	(IDM_WINDOW_MRU_LIMIT + 1)
-    #define  IDM_WINDOW_COPY_PATH 	(IDM_WINDOW_MRU_LIMIT + 2)
-
-#define IDR_DROPLIST_MENU 14000
-    #define    IDM_DROPLIST_LIST           (IDR_DROPLIST_MENU + 1)
-    #define    IDM_DROPLIST_MRU_FIRST      (IDR_DROPLIST_MENU + 20)
